import { EventEmitter } from '../../../stencil-public-runtime';
import { DeckdeckgoChart } from '../deckdeckgo-chart';
import 'd3-transition';
import { DeckdeckgoBarChartData, DeckdeckgoBarChartDataValue } from '@deckdeckgo/types';
export declare class DeckdeckgoBarChart implements DeckdeckgoChart {
  el: HTMLElement;
  /**
   * The width of the chart
   */
  width: number;
  /**
   * The height of the chart
   */
  height: number;
  /**
   * The path to the source file of the data
   */
  src: string;
  /**
   * The line separator use in your csv file
   */
  separator: string;
  /**
   * Set to `true` in case you would like to load (fetch) the data by yourself. Useful in case your data are protected with a token.
   */
  customLoader: boolean;
  /**
   * The margin top of the chart in pixel
   */
  marginTop: number;
  /**
   * The margin bottom of the chart in pixel
   */
  marginBottom: number;
  /**
   * The margin left of the chart in pixel
   */
  marginLeft: number;
  /**
   * The margin right of the chart in pixel
   */
  marginRight: number;
  /**
   * Display multiple graphs and animate the transition between these
   */
  animation: boolean;
  /**
   * Duration of the transition between graphs
   */
  animationDuration: number;
  private svg;
  private x0;
  private x1;
  private y;
  /**
   * Instead of a source file, source data can also be provided as an array of `DeckdeckgoBarChartData`
   */
  data: DeckdeckgoBarChartData[];
  private chartData;
  private barDataIndex;
  private randomColors;
  /**
   * If `false`, no axis y will be draw.
   */
  yAxis: boolean;
  /**
   * Set a minimal value for the y Axis. Useful in case the series of data could contains only zeros.
   */
  yAxisMin: number;
  /**
   * The event to be processed to load the data if you are using a custom loader.
   * @private
   */
  chartCustomLoad: EventEmitter<string>;
  /**
   * Emit the random colors that are generated for the charts.
   */
  chartRandomColor: EventEmitter<string[]>;
  componentDidLoad(): Promise<void>;
  onSrcChange(): Promise<void>;
  onDataChange(): Promise<void>;
  /**
   * This is the method we are using to refresh the current bar chart when an audience is participating to live vote. It will not redraw the axis but it will draw and animate the bars.
   * @param values
   */
  updateCurrentBar(values: DeckdeckgoBarChartDataValue[]): Promise<void>;
  /**
   * In case you would like to redraw your chart, for example on resize of the window.
   * @param width
   * @param height
   */
  draw(width?: number, height?: number): Promise<void>;
  private firstDraw;
  private initRandomColors;
  private drawBars;
  private initAxisXDomain;
  private initAxisYDomain;
  /**
   * If you are using animation, this method is used to display the next data respectively the next chart.
   */
  next(): Promise<void>;
  /**
   * If you are using animation, this method is used to display the previous data respectively the previous chart.
   */
  prev(): Promise<void>;
  private prevNext;
  /**
   * Is animation at the begin of the serie.
   */
  isBeginning(): Promise<boolean>;
  /**
   * Is animation at the end of the serie.
   */
  isEnd(): Promise<boolean>;
  private drawAxis;
  private initAxis;
  private initAnimatedAxisX;
  private initInstantAxisX;
  private drawAnimatedBars;
  private drawInstantBars;
  private style;
  fetchData(): Promise<DeckdeckgoBarChartData[]>;
  /**
   * If you "manually" load the data, call this method once the text content fetched.
   * @param content
   */
  postCustomLoad(content: string | undefined): Promise<void>;
  private loadContent;
  render(): any;
}
