import { EventEmitter } from '../../../stencil-public-runtime';
import 'd3-transition';
import { DeckdeckgoChart } from '../deckdeckgo-chart';
interface DeckdeckgoLineChartData {
  when: Date | number;
  value: number;
}
interface DeckdeckgoLineChartSerie {
  data: DeckdeckgoLineChartData[];
  randomFillColor: string;
}
export declare class DeckdeckgoLineChart implements DeckdeckgoChart {
  el: HTMLElement;
  /**
   * The width of the chart
   */
  width: number;
  /**
   * The height of the chart
   */
  height: number;
  /**
   * The path to the source file of the data
   */
  src: string;
  /**
   * The line separator use in your csv file
   */
  separator: string;
  /**
   * Set to `true` in case you would like to load (fetch) the data by yourself. Useful in case your data are protected with a token.
   */
  customLoader: boolean;
  /**
   * The pattern for the dates. All supported date format: https://date-fns.org/v2.0.0-alpha.26/docs/parse.
   */
  datePattern: string;
  /**
   * The margin top of the chart in pixel
   */
  marginTop: number;
  /**
   * The margin bottom of the chart in pixel
   */
  marginBottom: number;
  /**
   * The margin left of the chart in pixel
   */
  marginLeft: number;
  /**
   * The margin right of the chart in pixel
   */
  marginRight: number;
  /**
   * The y axis behavior.
   */
  yAxisDomain: string;
  /**
   * Render smooth lines or with edges.
   */
  smooth: boolean;
  /**
   * Draw the area.
   */
  area: boolean;
  /**
   * Render ticks on the axes.
   */
  ticks: number;
  /**
   * Render a grid behind the chart.
   */
  grid: boolean;
  /**
   * Display multiple graphs and animate the transition between these
   */
  animation: boolean;
  /**
   * Duration of the transition between graphs
   */
  animationDuration: number;
  /**
   * The event to be processed to load the data if you are using a custom loader.
   * @private
   */
  chartCustomLoad: EventEmitter<string>;
  /**
   * Emit the random colors that are generated for the charts.
   */
  chartRandomColor: EventEmitter<string[]>;
  private svg;
  private x;
  private y;
  private series;
  private serieIndex;
  private randomFillColors;
  componentDidLoad(): Promise<void>;
  redraw(): Promise<void>;
  /**
   * In case you would like to redraw your chart, for example on resize of the window.
   * @param width
   * @param height
   */
  draw(width?: number, height?: number): Promise<void>;
  private firstDraw;
  /**
   * If you are using animation, this method is used to display the next data respectively the next chart.
   */
  next(): Promise<void>;
  /**
   * If you are using animation, this method is used to display the previous data respectively the previous chart.
   */
  prev(): Promise<void>;
  private prevNext;
  /**
   * Is animation at the begin of the serie.
   */
  isBeginning(): Promise<boolean>;
  /**
   * Is animation at the end of the serie.
   */
  isEnd(): Promise<boolean>;
  private initAxis;
  private findMinMaxValues;
  private concatMinMax;
  private findMinMax;
  private drawAxis;
  private drawLine;
  private drawInstantLine;
  private drawAnimatedLine;
  fetchData(): Promise<DeckdeckgoLineChartSerie[]>;
  postCustomLoad(content: string | undefined): Promise<void>;
  private loadContent;
  private validDate;
  render(): any;
}
export {};
