import { EventEmitter } from '../../../stencil-public-runtime';
import { DeckdeckgoChart } from '../deckdeckgo-chart';
import 'd3-transition';
interface DeckdeckgoPieChartDataValue {
  label: string;
  value: number;
  randomFillColor: string;
  key: number;
}
interface DeckdeckgoPieChartData {
  values: DeckdeckgoPieChartDataValue[];
}
export declare class DeckdeckgoPieChart implements DeckdeckgoChart {
  el: HTMLElement;
  /**
   * The width of the chart
   */
  width: number;
  /**
   * The height of the chart
   */
  height: number;
  /**
   * The margin top of the chart in pixel
   */
  marginTop: number;
  /**
   * The margin bottom of the chart in pixel
   */
  marginBottom: number;
  /**
   * The margin left of the chart in pixel
   */
  marginLeft: number;
  /**
   * The margin right of the chart in pixel
   */
  marginRight: number;
  /**
   * The inner radius of the pie
   */
  innerRadius: number;
  /**
   * The path to the source file of the data
   */
  src: string;
  /**
   * The line separator use in your csv file
   */
  separator: string;
  /**
   * Set to `true` in case you would like to load (fetch) the data by yourself. Useful in case your data are protected with a token.
   */
  customLoader: boolean;
  /**
   * Display multiple graphs and animate the transition between these
   */
  animation: boolean;
  /**
   * Duration of the transition between graphs
   */
  animationDuration: number;
  /**
   * The event to be processed to load the data if you are using a custom loader.
   * @private
   */
  chartCustomLoad: EventEmitter<string>;
  /**
   * Emit the random colors that are generated for the charts.
   */
  chartRandomColor: EventEmitter<string[]>;
  private svg;
  private myPath;
  private data;
  private pieDataIndex;
  private randomColors;
  componentDidLoad(): Promise<void>;
  redraw(): Promise<void>;
  /**
   * In case you would like to redraw your chart, for example on resize of the window.
   * @param width
   * @param height
   */
  draw(width?: number, height?: number): Promise<void>;
  /**
   * If you are using animation, this method is used to display the next data respectively the next chart.
   */
  next(): Promise<void>;
  /**
   * If you are using animation, this method is used to display the previous data respectively the previous chart.
   */
  prev(): Promise<void>;
  private prevNext;
  /**
   * Is animation at the begin of the serie.
   */
  isBeginning(): Promise<boolean>;
  /**
   * Is animation at the end of the serie.
   */
  isEnd(): Promise<boolean>;
  private drawPie;
  private drawPieForData;
  private createPieData;
  private appendLabel;
  fetchData(): Promise<DeckdeckgoPieChartData[]>;
  postCustomLoad(content: string | undefined): Promise<void>;
  private loadContent;
  private initRandomColors;
  render(): any;
}
export {};
